==> percona-server-mongodb_4.0.25.orig.tar.gz: percona-server-mongodb-4.0.25-20/aws-sdk-cpp/aws-cpp-sdk-eventbridge/source/EventBridgeEndpoint.cpp <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/eventbridge/EventBridgeEndpoint.h>
#include <aws/core/utils/memory/stl/AWSStringStream.h>
#include <aws/core/utils/HashingUtils.h>

using namespace Aws;
using namespace Aws::EventBridge;

namespace Aws
{
namespace EventBridge
{
namespace EventBridgeEndpoint
{
  static const int CN_NORTH_1_HASH = Aws::Utils::HashingUtils::HashString("cn-north-1");
  static const int CN_NORTHWEST_1_HASH = Aws::Utils::HashingUtils::HashString("cn-northwest-1");
  static const int US_ISO_EAST_1_HASH = Aws::Utils::HashingUtils::HashString("us-iso-east-1");
  static const int US_ISOB_EAST_1_HASH = Aws::Utils::HashingUtils::HashString("us-isob-east-1");


  Aws::String ForRegion(const Aws::String& regionName, bool useDualStack)
  {
    // Fallback to us-east-1 if global endpoint does not exists.
    Aws::String region = regionName == Aws::Region::AWS_GLOBAL ? Aws::Region::US_EAST_1 : regionName;
    auto hash = Aws::Utils::HashingUtils::HashString(region.c_str());

    Aws::StringStream ss;
    ss << "events" << ".";

    if(useDualStack)
    {
      ss << "dualstack.";
    }

    ss << region;

    if (hash == CN_NORTH_1_HASH || hash == CN_NORTHWEST_1_HASH)
    {
      ss << ".amazonaws.com.cn";
    }
    else if (hash == US_ISO_EAST_1_HASH)
    {
      ss << ".c2s.ic.gov";
    }
    else if (hash == US_ISOB_EAST_1_HASH)
    {
      ss << ".sc2s.sgov.gov";
    }
    else
    {
      ss << ".amazonaws.com";
    }

    return ss.str();
  }

} // namespace EventBridgeEndpoint
} // namespace EventBridge
} // namespace Aws

==> percona-server-mongodb_8.0.12.orig.tar.gz: percona-server-mongodb-8.0.12-4/aws-sdk-cpp/aws-cpp-sdk-eventbridge/source/EventBridgeEndpoint.cpp <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/eventbridge/EventBridgeEndpoint.h>
#include <aws/core/utils/memory/stl/AWSStringStream.h>
#include <aws/core/utils/HashingUtils.h>

using namespace Aws;
using namespace Aws::EventBridge;

namespace Aws
{
namespace EventBridge
{
namespace EventBridgeEndpoint
{
  static const int CN_NORTH_1_HASH = Aws::Utils::HashingUtils::HashString("cn-north-1");
  static const int CN_NORTHWEST_1_HASH = Aws::Utils::HashingUtils::HashString("cn-northwest-1");
  static const int US_ISO_EAST_1_HASH = Aws::Utils::HashingUtils::HashString("us-iso-east-1");
  static const int US_ISOB_EAST_1_HASH = Aws::Utils::HashingUtils::HashString("us-isob-east-1");
  static const int US_ISO_WEST_1_HASH = Aws::Utils::HashingUtils::HashString("us-iso-west-1");


  Aws::String ForRegion(const Aws::String& regionName, bool useDualStack)
  {
    // Fallback to us-east-1 if global endpoint does not exists.
    Aws::String region = regionName == Aws::Region::AWS_GLOBAL ? Aws::Region::US_EAST_1 : regionName;
    auto hash = Aws::Utils::HashingUtils::HashString(region.c_str());

    Aws::StringStream ss;
    ss << "events" << ".";

    if(useDualStack)
    {
      ss << "dualstack.";
    }

    ss << region;

    if (hash == CN_NORTH_1_HASH || hash == CN_NORTHWEST_1_HASH)
    {
      ss << ".amazonaws.com.cn";
    }
    else if (hash == US_ISO_EAST_1_HASH || hash == US_ISO_WEST_1_HASH)
    {
      ss << ".c2s.ic.gov";
    }
    else if (hash == US_ISOB_EAST_1_HASH)
    {
      ss << ".sc2s.sgov.gov";
    }
    else
    {
      ss << ".amazonaws.com";
    }

    return ss.str();
  }

  Aws::String GetEventBridgeSuffix(const Aws::String& regionName, bool useDualStack)
  {
    auto hash = Aws::Utils::HashingUtils::HashString(regionName.c_str());

    Aws::StringStream ss;

    ss << ".events.";

    if(useDualStack)
    {
      ss << "api.aws";
    }
    else
    {
      if (hash == CN_NORTH_1_HASH || hash == CN_NORTHWEST_1_HASH)
      {
        ss << "amazonaws.com.cn";
      }
      else if (hash == US_ISO_EAST_1_HASH)
      {
        ss << "c2s.ic.gov";
      }
      else if (hash == US_ISOB_EAST_1_HASH)
      {
        ss << "sc2s.sgov.gov";
      }
      else
      {
        ss << "amazonaws.com";
      }
    }

    return ss.str();
  }

} // namespace EventBridgeEndpoint
} // namespace EventBridge
} // namespace Aws
